pub struct UnifiedCommandExecutor { /* private fields */ }Expand description
Unified command executor that provides parity across platforms
Implementations
Sourceimpl UnifiedCommandExecutor
impl UnifiedCommandExecutor
Sourcepub fn new(config: UnifiedExecutorConfig) -> Result<Self, UbiquityError>
pub fn new(config: UnifiedExecutorConfig) -> Result<Self, UbiquityError>
Create a new unified executor with the given configuration
Sourcepub fn auto() -> Result<Self, UbiquityError>
pub fn auto() -> Result<Self, UbiquityError>
Create a new unified executor with automatic mode detection
Sourcepub fn mode(&self) -> ExecutionMode
pub fn mode(&self) -> ExecutionMode
Get the current execution mode
Sourcepub fn switch_mode(&mut self, mode: ExecutionMode) -> Result<(), UbiquityError>
pub fn switch_mode(&mut self, mode: ExecutionMode) -> Result<(), UbiquityError>
Switch to a different execution mode
Sourcepub fn command(&self, command: impl Into<String>) -> CommandBuilder<'_>
pub fn command(&self, command: impl Into<String>) -> CommandBuilder<'_>
Create a command builder